summaryrefslogtreecommitdiff
path: root/util
diff options
context:
space:
mode:
Diffstat (limited to 'util')
-rw-r--r--util/Makefile.in287
-rw-r--r--util/ievents.c2
-rw-r--r--util/ilan.c62
-rw-r--r--util/ipmicmd.h1
-rw-r--r--util/ipmilan2.c5
-rw-r--r--util/ipmilanplus.c46
-rw-r--r--util/ipmiutil.c2
-rw-r--r--util/isensor.c5
-rw-r--r--util/oem_supermicro.c3
-rw-r--r--util/subs.c3
10 files changed, 315 insertions, 101 deletions
diff --git a/util/Makefile.in b/util/Makefile.in
index 4358683..2909704 100644
--- a/util/Makefile.in
+++ b/util/Makefile.in
@@ -1,7 +1,7 @@
-# Makefile.in generated by automake 1.13.4 from Makefile.am.
+# Makefile.in generated by automake 1.16.1 from Makefile.am.
# @configure_input@
-# Copyright (C) 1994-2013 Free Software Foundation, Inc.
+# Copyright (C) 1994-2018 Free Software Foundation, Inc.
# This Makefile.in is free software; the Free Software Foundation
# gives unlimited permission to copy and/or distribute it,
@@ -15,7 +15,17 @@
@SET_MAKE@
VPATH = @srcdir@
-am__is_gnu_make = test -n '$(MAKEFILE_LIST)' && test -n '$(MAKELEVEL)'
+am__is_gnu_make = { \
+ if test -z '$(MAKELEVEL)'; then \
+ false; \
+ elif test -n '$(MAKE_HOST)'; then \
+ true; \
+ elif test -n '$(MAKE_VERSION)' && test -n '$(CURDIR)'; then \
+ true; \
+ else \
+ false; \
+ fi; \
+}
am__make_running_with_option = \
case $${target_option-} in \
?) ;; \
@@ -82,12 +92,11 @@ bin_PROGRAMS = ipmiutil$(EXEEXT) ievents$(EXEEXT) idiscover$(EXEEXT)
sbin_PROGRAMS = ipmi_port$(EXEEXT) iseltime$(EXEEXT)
EXTRA_PROGRAMS = ipmi_sample$(EXEEXT) ipmi_sample_evt$(EXEEXT)
subdir = util
-DIST_COMMON = $(srcdir)/Makefile.in $(srcdir)/Makefile.am \
- $(top_srcdir)/mkinstalldirs $(top_srcdir)/depcomp
ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
am__aclocal_m4_deps = $(top_srcdir)/configure.ac
am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
$(ACLOCAL_M4)
+DIST_COMMON = $(srcdir)/Makefile.am $(am__DIST_COMMON)
mkinstalldirs = $(SHELL) $(top_srcdir)/mkinstalldirs
CONFIG_HEADER = $(top_builddir)/config.h
CONFIG_CLEAN_FILES =
@@ -160,7 +169,32 @@ am__v_at_0 = @
am__v_at_1 =
DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
depcomp = $(SHELL) $(top_srcdir)/depcomp
-am__depfiles_maybe = depfiles
+am__maybe_remake_depfiles = depfiles
+am__depfiles_remade = ./$(DEPDIR)/ialarms.Po ./$(DEPDIR)/icmd.Po \
+ ./$(DEPDIR)/iconfig.Po ./$(DEPDIR)/idcmi.Po \
+ ./$(DEPDIR)/idiscover.Po ./$(DEPDIR)/iekanalyzer.Po \
+ ./$(DEPDIR)/ievents.Po ./$(DEPDIR)/ifirewall.Po \
+ ./$(DEPDIR)/ifru.Po ./$(DEPDIR)/ifru_picmg.Po \
+ ./$(DEPDIR)/ifwum.Po ./$(DEPDIR)/igetevent.Po \
+ ./$(DEPDIR)/ihealth.Po ./$(DEPDIR)/ihpm.Po ./$(DEPDIR)/ilan.Po \
+ ./$(DEPDIR)/imbapi.Po ./$(DEPDIR)/ipicmg.Po \
+ ./$(DEPDIR)/ipmi_port.Po ./$(DEPDIR)/ipmi_sample.Po \
+ ./$(DEPDIR)/ipmi_sample_evt.Po ./$(DEPDIR)/ipmibmc.Po \
+ ./$(DEPDIR)/ipmicmd.Po ./$(DEPDIR)/ipmidir.Po \
+ ./$(DEPDIR)/ipmilan.Po ./$(DEPDIR)/ipmilanplus.Po \
+ ./$(DEPDIR)/ipmild.Po ./$(DEPDIR)/ipmilipmi.Po \
+ ./$(DEPDIR)/ipmimv.Po ./$(DEPDIR)/ipmiutil.Po \
+ ./$(DEPDIR)/ireset.Po ./$(DEPDIR)/isel.Po \
+ ./$(DEPDIR)/iseltime.Po ./$(DEPDIR)/isensor.Po \
+ ./$(DEPDIR)/iserial.Po ./$(DEPDIR)/isol.Po \
+ ./$(DEPDIR)/itsol.Po ./$(DEPDIR)/iuser.Po ./$(DEPDIR)/iwdt.Po \
+ ./$(DEPDIR)/md2.Po ./$(DEPDIR)/md5.Po ./$(DEPDIR)/mem_if.Po \
+ ./$(DEPDIR)/oem_asus.Po ./$(DEPDIR)/oem_dell.Po \
+ ./$(DEPDIR)/oem_fujitsu.Po ./$(DEPDIR)/oem_hp.Po \
+ ./$(DEPDIR)/oem_intel.Po ./$(DEPDIR)/oem_kontron.Po \
+ ./$(DEPDIR)/oem_lenovo.Po ./$(DEPDIR)/oem_newisys.Po \
+ ./$(DEPDIR)/oem_quanta.Po ./$(DEPDIR)/oem_sun.Po \
+ ./$(DEPDIR)/oem_supermicro.Po ./$(DEPDIR)/subs.Po
am__mv = mv -f
COMPILE = $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) \
$(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
@@ -209,6 +243,8 @@ am__define_uniq_tagged_files = \
done | $(am__uniquify_input)`
ETAGS = etags
CTAGS = ctags
+am__DIST_COMMON = $(srcdir)/Makefile.in $(top_srcdir)/depcomp \
+ $(top_srcdir)/mkinstalldirs
DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
ACLOCAL = @ACLOCAL@
AMTAR = @AMTAR@
@@ -265,6 +301,7 @@ LIB_DIR = @LIB_DIR@
LIPO = @LIPO@
LN_S = @LN_S@
LTLIBOBJS = @LTLIBOBJS@
+LT_SYS_LIBRARY_PATH = @LT_SYS_LIBRARY_PATH@
MAKEINFO = @MAKEINFO@
MANIFEST_TOOL = @MANIFEST_TOOL@
MKDIR_P = @MKDIR_P@
@@ -430,14 +467,13 @@ $(srcdir)/Makefile.in: $(srcdir)/Makefile.am $(am__configure_deps)
echo ' cd $(top_srcdir) && $(AUTOMAKE) --foreign util/Makefile'; \
$(am__cd) $(top_srcdir) && \
$(AUTOMAKE) --foreign util/Makefile
-.PRECIOUS: Makefile
Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
@case '$?' in \
*config.status*) \
cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
*) \
- echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
- cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+ echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__maybe_remake_depfiles)'; \
+ cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__maybe_remake_depfiles);; \
esac;
$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
@@ -553,73 +589,79 @@ mostlyclean-compile:
distclean-compile:
-rm -f *.tab.c
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ialarms.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/icmd.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iconfig.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/idcmi.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/idiscover.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iekanalyzer.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ievents.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifirewall.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifru.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifru_picmg.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifwum.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/igetevent.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ihealth.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ihpm.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ilan.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/imbapi.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipicmg.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_port.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_sample.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_sample_evt.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmibmc.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmicmd.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmidir.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilan.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilanplus.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmild.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilipmi.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmimv.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmiutil.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ireset.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isel.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iseltime.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isensor.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iserial.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isol.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/itsol.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iuser.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iwdt.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/md2.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/md5.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mem_if.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_asus.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_dell.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_fujitsu.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_hp.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_intel.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_kontron.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_lenovo.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_newisys.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_quanta.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_sun.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_supermicro.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/subs.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ialarms.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/icmd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iconfig.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/idcmi.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/idiscover.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iekanalyzer.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ievents.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifirewall.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifru.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifru_picmg.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ifwum.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/igetevent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ihealth.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ihpm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ilan.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/imbapi.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipicmg.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_port.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_sample.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmi_sample_evt.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmibmc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmicmd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmidir.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilan.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilanplus.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmild.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmilipmi.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmimv.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipmiutil.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ireset.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isel.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iseltime.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isensor.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iserial.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/isol.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/itsol.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iuser.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iwdt.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/md2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/md5.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mem_if.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_asus.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_dell.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_fujitsu.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_hp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_intel.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_kontron.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_lenovo.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_newisys.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_quanta.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_sun.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/oem_supermicro.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/subs.Po@am__quote@ # am--include-marker
+
+$(am__depfiles_remade):
+ @$(MKDIR_P) $(@D)
+ @echo '# dummy' >$@-t && $(am__mv) $@-t $@
+
+am--depfiles: $(am__depfiles_remade)
.c.o:
@am__fastdepCC_TRUE@ $(AM_V_CC)$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
@am__fastdepCC_TRUE@ $(AM_V_at)$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
@AMDEP_TRUE@@am__fastdepCC_FALSE@ $(AM_V_CC)source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c $<
+@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c -o $@ $<
.c.obj:
@am__fastdepCC_TRUE@ $(AM_V_CC)$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
@am__fastdepCC_TRUE@ $(AM_V_at)$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
@AMDEP_TRUE@@am__fastdepCC_FALSE@ $(AM_V_CC)source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c `$(CYGPATH_W) '$<'`
+@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
.c.lo:
@am__fastdepCC_TRUE@ $(AM_V_CC)$(LTCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
@@ -686,7 +728,10 @@ cscopelist-am: $(am__tagged_files)
distclean-tags:
-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
-distdir: $(DISTFILES)
+distdir: $(BUILT_SOURCES)
+ $(MAKE) $(AM_MAKEFLAGS) distdir-am
+
+distdir-am: $(DISTFILES)
@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
list='$(DISTFILES)'; \
@@ -757,7 +802,59 @@ clean-am: clean-binPROGRAMS clean-generic clean-libtool \
clean-sbinPROGRAMS mostlyclean-am
distclean: distclean-am
- -rm -rf ./$(DEPDIR)
+ -rm -f ./$(DEPDIR)/ialarms.Po
+ -rm -f ./$(DEPDIR)/icmd.Po
+ -rm -f ./$(DEPDIR)/iconfig.Po
+ -rm -f ./$(DEPDIR)/idcmi.Po
+ -rm -f ./$(DEPDIR)/idiscover.Po
+ -rm -f ./$(DEPDIR)/iekanalyzer.Po
+ -rm -f ./$(DEPDIR)/ievents.Po
+ -rm -f ./$(DEPDIR)/ifirewall.Po
+ -rm -f ./$(DEPDIR)/ifru.Po
+ -rm -f ./$(DEPDIR)/ifru_picmg.Po
+ -rm -f ./$(DEPDIR)/ifwum.Po
+ -rm -f ./$(DEPDIR)/igetevent.Po
+ -rm -f ./$(DEPDIR)/ihealth.Po
+ -rm -f ./$(DEPDIR)/ihpm.Po
+ -rm -f ./$(DEPDIR)/ilan.Po
+ -rm -f ./$(DEPDIR)/imbapi.Po
+ -rm -f ./$(DEPDIR)/ipicmg.Po
+ -rm -f ./$(DEPDIR)/ipmi_port.Po
+ -rm -f ./$(DEPDIR)/ipmi_sample.Po
+ -rm -f ./$(DEPDIR)/ipmi_sample_evt.Po
+ -rm -f ./$(DEPDIR)/ipmibmc.Po
+ -rm -f ./$(DEPDIR)/ipmicmd.Po
+ -rm -f ./$(DEPDIR)/ipmidir.Po
+ -rm -f ./$(DEPDIR)/ipmilan.Po
+ -rm -f ./$(DEPDIR)/ipmilanplus.Po
+ -rm -f ./$(DEPDIR)/ipmild.Po
+ -rm -f ./$(DEPDIR)/ipmilipmi.Po
+ -rm -f ./$(DEPDIR)/ipmimv.Po
+ -rm -f ./$(DEPDIR)/ipmiutil.Po
+ -rm -f ./$(DEPDIR)/ireset.Po
+ -rm -f ./$(DEPDIR)/isel.Po
+ -rm -f ./$(DEPDIR)/iseltime.Po
+ -rm -f ./$(DEPDIR)/isensor.Po
+ -rm -f ./$(DEPDIR)/iserial.Po
+ -rm -f ./$(DEPDIR)/isol.Po
+ -rm -f ./$(DEPDIR)/itsol.Po
+ -rm -f ./$(DEPDIR)/iuser.Po
+ -rm -f ./$(DEPDIR)/iwdt.Po
+ -rm -f ./$(DEPDIR)/md2.Po
+ -rm -f ./$(DEPDIR)/md5.Po
+ -rm -f ./$(DEPDIR)/mem_if.Po
+ -rm -f ./$(DEPDIR)/oem_asus.Po
+ -rm -f ./$(DEPDIR)/oem_dell.Po
+ -rm -f ./$(DEPDIR)/oem_fujitsu.Po
+ -rm -f ./$(DEPDIR)/oem_hp.Po
+ -rm -f ./$(DEPDIR)/oem_intel.Po
+ -rm -f ./$(DEPDIR)/oem_kontron.Po
+ -rm -f ./$(DEPDIR)/oem_lenovo.Po
+ -rm -f ./$(DEPDIR)/oem_newisys.Po
+ -rm -f ./$(DEPDIR)/oem_quanta.Po
+ -rm -f ./$(DEPDIR)/oem_sun.Po
+ -rm -f ./$(DEPDIR)/oem_supermicro.Po
+ -rm -f ./$(DEPDIR)/subs.Po
-rm -f Makefile
distclean-am: clean-am distclean-compile distclean-generic \
distclean-tags
@@ -801,7 +898,59 @@ install-ps-am:
installcheck-am:
maintainer-clean: maintainer-clean-am
- -rm -rf ./$(DEPDIR)
+ -rm -f ./$(DEPDIR)/ialarms.Po
+ -rm -f ./$(DEPDIR)/icmd.Po
+ -rm -f ./$(DEPDIR)/iconfig.Po
+ -rm -f ./$(DEPDIR)/idcmi.Po
+ -rm -f ./$(DEPDIR)/idiscover.Po
+ -rm -f ./$(DEPDIR)/iekanalyzer.Po
+ -rm -f ./$(DEPDIR)/ievents.Po
+ -rm -f ./$(DEPDIR)/ifirewall.Po
+ -rm -f ./$(DEPDIR)/ifru.Po
+ -rm -f ./$(DEPDIR)/ifru_picmg.Po
+ -rm -f ./$(DEPDIR)/ifwum.Po
+ -rm -f ./$(DEPDIR)/igetevent.Po
+ -rm -f ./$(DEPDIR)/ihealth.Po
+ -rm -f ./$(DEPDIR)/ihpm.Po
+ -rm -f ./$(DEPDIR)/ilan.Po
+ -rm -f ./$(DEPDIR)/imbapi.Po
+ -rm -f ./$(DEPDIR)/ipicmg.Po
+ -rm -f ./$(DEPDIR)/ipmi_port.Po
+ -rm -f ./$(DEPDIR)/ipmi_sample.Po
+ -rm -f ./$(DEPDIR)/ipmi_sample_evt.Po
+ -rm -f ./$(DEPDIR)/ipmibmc.Po
+ -rm -f ./$(DEPDIR)/ipmicmd.Po
+ -rm -f ./$(DEPDIR)/ipmidir.Po
+ -rm -f ./$(DEPDIR)/ipmilan.Po
+ -rm -f ./$(DEPDIR)/ipmilanplus.Po
+ -rm -f ./$(DEPDIR)/ipmild.Po
+ -rm -f ./$(DEPDIR)/ipmilipmi.Po
+ -rm -f ./$(DEPDIR)/ipmimv.Po
+ -rm -f ./$(DEPDIR)/ipmiutil.Po
+ -rm -f ./$(DEPDIR)/ireset.Po
+ -rm -f ./$(DEPDIR)/isel.Po
+ -rm -f ./$(DEPDIR)/iseltime.Po
+ -rm -f ./$(DEPDIR)/isensor.Po
+ -rm -f ./$(DEPDIR)/iserial.Po
+ -rm -f ./$(DEPDIR)/isol.Po
+ -rm -f ./$(DEPDIR)/itsol.Po
+ -rm -f ./$(DEPDIR)/iuser.Po
+ -rm -f ./$(DEPDIR)/iwdt.Po
+ -rm -f ./$(DEPDIR)/md2.Po
+ -rm -f ./$(DEPDIR)/md5.Po
+ -rm -f ./$(DEPDIR)/mem_if.Po
+ -rm -f ./$(DEPDIR)/oem_asus.Po
+ -rm -f ./$(DEPDIR)/oem_dell.Po
+ -rm -f ./$(DEPDIR)/oem_fujitsu.Po
+ -rm -f ./$(DEPDIR)/oem_hp.Po
+ -rm -f ./$(DEPDIR)/oem_intel.Po
+ -rm -f ./$(DEPDIR)/oem_kontron.Po
+ -rm -f ./$(DEPDIR)/oem_lenovo.Po
+ -rm -f ./$(DEPDIR)/oem_newisys.Po
+ -rm -f ./$(DEPDIR)/oem_quanta.Po
+ -rm -f ./$(DEPDIR)/oem_sun.Po
+ -rm -f ./$(DEPDIR)/oem_supermicro.Po
+ -rm -f ./$(DEPDIR)/subs.Po
-rm -f Makefile
maintainer-clean-am: distclean-am maintainer-clean-generic
@@ -822,7 +971,7 @@ uninstall-am: uninstall-binPROGRAMS uninstall-sbinPROGRAMS
.MAKE: install-am install-strip
-.PHONY: CTAGS GTAGS TAGS all all-am check check-am clean \
+.PHONY: CTAGS GTAGS TAGS all all-am am--depfiles check check-am clean \
clean-binPROGRAMS clean-generic clean-libtool \
clean-sbinPROGRAMS cscopelist-am ctags ctags-am distclean \
distclean-compile distclean-generic distclean-libtool \
@@ -838,6 +987,8 @@ uninstall-am: uninstall-binPROGRAMS uninstall-sbinPROGRAMS
tags tags-am uninstall uninstall-am uninstall-binPROGRAMS \
uninstall-sbinPROGRAMS
+.PRECIOUS: Makefile
+
# To build an imb api library (libimbapi.a):
libimbapi.a: imbapi.c
diff --git a/util/ievents.c b/util/ievents.c
index ff98ef4..e5d34f7 100644
--- a/util/ievents.c
+++ b/util/ievents.c
@@ -80,7 +80,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
extern char *progver; /*from ipmiutil.c*/
static char * progname = "ipmiutil events";
#else
-static char *progver = "3.17";
+static char *progver = "3.18";
static char *progname = "ievents";
#endif
static char fsensdesc = 0; /* 1= get extended sensor descriptions*/
diff --git a/util/ipmicmd.h b/util/ipmicmd.h
index 5fccaea..17deca2 100644
--- a/util/ipmicmd.h
+++ b/util/ipmicmd.h
@@ -315,6 +315,7 @@ struct oemvalstr {
#define VENDOR_LENOVO 0x004A66
#define VENDOR_LENOVO2 0x004F4D
#define VENDOR_ASUS 0x000A3F
+#define VENDOR_MITAC 6653 /*=0x19FD*/
#define PRODUCT_QUANTA_S99Q 21401
#define PRODUCT_QUANTA_QSSC_S4R 64 /*0x0040*/
diff --git a/util/ipmilan2.c b/util/ipmilan2.c
index 0ff2fac..4d0bcc3 100644
--- a/util/ipmilan2.c
+++ b/util/ipmilan2.c
@@ -30,7 +30,10 @@ void set_loglevel(int level);
void lprintf(int level, const char * format, ...);
int ipmi_open_lan2(char *node, char *user, char *pswd, int fdebugcmd)
-{ if (fdebugcmd) verbose = 1; return(LAN_ERR_INVPARAM); }
+{ if (fdebugcmd) verbose = 1;
+ printf("ipmi_open_lan2: lanplus not configured\n");
+ return(LAN_ERR_INVPARAM);
+}
int ipmi_close_lan2(char *node)
{ return(LAN_ERR_INVPARAM); }
diff --git a/util/ipmilanplus.c b/util/ipmilanplus.c
index f018b36..d3ea3c3 100644
--- a/util/ipmilanplus.c
+++ b/util/ipmilanplus.c
@@ -1,7 +1,7 @@
/*
* ipmilanplus.c
*
- * Interface to call libintf_lanplus from ipmitool to do RMCP+ protocol.
+ * Interface to call libintf_lanplus to do RMCP+ protocol.
*
* 01/09/07 Andy Cress - created
* 02/22/07 Andy Cress - initialize cipher_suite to 3 (was 0)
@@ -42,7 +42,10 @@ struct oemvalstr {
const char * str;
};
int ipmi_open_lan2(char *node, char *user, char *pswd, int fdebugcmd)
-{ if (fdebugcmd) verbose = 1; return(LAN_ERR_INVPARAM); }
+{ if (fdebugcmd) verbose = 1;
+ printf("ipmi_open_lan2: lanplus not configured\n");
+ return(LAN_ERR_INVPARAM);
+}
int ipmi_close_lan2(char *node)
{ return(LAN_ERR_INVPARAM); }
@@ -92,7 +95,7 @@ static void sol_output_handler(void *rsp) { return; }
static void dbg_dump(char *tag, uchar *pdata, int len, int fascii) { return; }
#endif
int ipmi_close_lan2(char *node); /*prototype*/
-extern LAN_OPT lanp; /* from ipmicmd.c */
+extern LAN_OPT lanp; /* LAN_OPT global from ipmicmd.c */
//extern char *gnode; /* from ipmicmd.c */
//extern char *guser; /* from ipmicmd.c */
//extern char *gpswd; /* from ipmicmd.c */
@@ -240,6 +243,7 @@ int ipmi_open_lan2(char *node, char *puser, char *pswd, int fdebugcmd)
else if (fdebugcmd) fdebugcmd = 1; /*debug, no packets*/
if (fdebugcmd) fdebugcmd = 4; /*max debug*/
#endif
+ if (fdebugcmd) fdebugcmd = 4; /*max debug ++++*/
switch (fdebugcmd) {
case 4: /* max debug */
loglvl = 8; /* 8=(LOG_DEBUG=1, max), 7=LOG_DEBUG */
@@ -315,9 +319,13 @@ int ipmi_open_lan2(char *node, char *puser, char *pswd, int fdebugcmd)
strncpy(intf->session->authcode, pswd, n);
}
rv = intf->open(intf);
- if (fdebugcmd)
+#ifdef WIN32
+ /* this debug can cause problems */
+ if (fdebugcmd)
printf("lan2 open.intf(auth=%d,priv=%d,cipher=%d) returned %d\n",
- lanp.auth_type,lanp.priv,lanp.cipher, rv);
+ 0,0,0,rv);
+ // lanp.auth_type,lanp.priv,lanp.cipher, rv);
+#endif
if (rv != -1) { /*success is >= 0*/
sol_seq = 0; /*init new session, will call inc_sol_seq*/
sol_len = 0;
@@ -447,13 +455,15 @@ int ipmi_cmd_lan2(char *node, ushort cmd, uchar *pdata, int sdata,
-#define NOEM 4
-static struct { int id; char *name; } oem_list[NOEM] = {
- {0x000157, "intelplus"}, /*VENDOR_INTEL*/
- {0x002A7C, "supermicro"}, /*VENDOR_SUPERMICRO*/
- /* { 0, "icts"}, *ICTS testware, needs user option*/
- {0x00000B, "hp"}, /*VENDOR_HP*/
- {0x000002, "ibm"} /*VENDOR_IBM*/
+#define NOEM 5
+static struct { int id; int prod; char *name; } oem_list[NOEM] = {
+ {0x000157, 0, "intelplus"}, /*VENDOR_INTEL*/
+ {0x002A7C, 0, "supermicro"}, /*VENDOR_SUPERMICRO*/
+ /* { 0, 0, "icts"}, *ICTS testware, needs user option*/
+ {0x000157, 0x002D, "i82571spt"}, /* Intel 82571 MAC with integrated RMCP+ support in super pass-through mode */
+ /* Is this ClearBay? Need to verify product id */
+ {0x00000B, 0, "hp"}, /*VENDOR_HP*/
+ {0x000002, 0, "ibm"} /*VENDOR_IBM*/
};
#ifdef METACOMMAND
extern int is_lan2intel(int vend, int prod); /*oem_intel.c*/
@@ -470,11 +480,12 @@ static int is_lan2intel(int vend, int prod) {
int ipmi_oem_active(struct ipmi_intf * intf, const char * oemtype)
{
int i, vend, prod, dtype;
+ if (intf == NULL || oemtype == NULL) return 0;
get_mfgid(&vend,&prod);
dtype = get_driver_type();
if (verbose)
lprintf(LOG_INFO,"oem_active(is_type==%s ?) vend=%x prod=%x", oemtype,vend,prod);
- if (strncmp("intelplus", oemtype, strlen(oemtype)) == 0) {
+ if (strncmp("intelplus", oemtype, 9) == 0) { /*was strlen(oemtype)*/
/* special case to detect intelplus, not all Intel platforms */
if (dtype == DRV_LAN2I) {
i = 1;
@@ -492,9 +503,14 @@ int ipmi_oem_active(struct ipmi_intf * intf, const char * oemtype)
} else {
// if (intf->oem == NULL) return 0;
for (i = 0; i < NOEM; i++) {
- if (strncmp(oem_list[i].name,oemtype,strlen(oemtype)) == 0)
+ if (strncmp(oem_list[i].name,oemtype,strlen(oem_list[i].name)) == 0)
if (oem_list[i].id == vend) {
- if (verbose) lprintf(LOG_WARN,"%s detected, vend=%x",oemtype,vend);
+ if (strncmp("i82571spt", oemtype, strlen(oem_list[i].name)) == 0) {
+ /* special case, check product id also */
+ if (oem_list[i].prod == prod) i = 1;
+ else i = 0;
+ }
+ if (verbose) lprintf(LOG_WARN,"oem_active: vend=%x detected, %s",vend,oemtype);
return 1;
}
}
diff --git a/util/ipmiutil.c b/util/ipmiutil.c
index 6acc19c..980c57e 100644
--- a/util/ipmiutil.c
+++ b/util/ipmiutil.c
@@ -57,7 +57,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#include "ipmiutil.h"
static char *progname = "ipmiutil";
-char *progver = "3.17";
+char *progver = "3.18";
// static char fdebug = 0;
/*int ipmiutil(int argc, char **argv); */
diff --git a/util/isensor.c b/util/isensor.c
index b2f2bf9..eded150 100644
--- a/util/isensor.c
+++ b/util/isensor.c
@@ -3660,7 +3660,7 @@ int i_sensor(int argc, char **argv)
if (ret != 0) {
if (ret == 0xC5) { /* lost Reservation ID, retry */
/*fprintf(stderr,"%04x lost reservation retrying to get, try: %d, %d, rlen = %d\n", recid,try,ret,sz);*/
- os_usleep((rand() & 3000), 0); //_sleep(rand() & 3000);
+ os_usleep((rand() & 3000),0);
fDoReserve = 1;
}
else {
@@ -3897,7 +3897,8 @@ NextSdr:
}
do_exit:
- if (fjumpstart) free_sdr_cache(psdrcache); /* does nothing if ==NULL*/
+ // if (fjumpstart)
+ free_sdr_cache(psdrcache); /* does nothing if ==NULL*/
/* show_outcome(progname,ret); *handled in ipmiutil.c*/
ipmi_close_();
return(ret);
diff --git a/util/oem_supermicro.c b/util/oem_supermicro.c
index 62ecbfe..69d75b0 100644
--- a/util/oem_supermicro.c
+++ b/util/oem_supermicro.c
@@ -575,11 +575,14 @@ int decode_mem_supermicro(int prod, uchar b2, uchar b3, char *desc, int *psz)
n = sprintf(desc,"P%d_DIMM%c%d",cpu,rgpair[pair],dimm);
}
/* Use DMI if we get confirmation about cpu/dimm indices. */
+#ifdef NOT
+ /* dangerous for some SuperMicro firmware/BIOS combos */
if (! is_remote()) {
fsm_debug = fdebug;
rv = get_MemDesc(cpu,dimm,desc,psz);
/* if (rv != 0) desc has "DIMM[%d}" */
}
+#endif
if ((bdata == 0xFF) || (rv != 0)) n = sprintf(desc,DIMM_UNKNOWN);
if (fdebug)
printf("decode_mem_supermicro: v%d bdata=%02x(%d) cpu=%d dimm=%d pair=%d\n",ver,bdata,bdata,cpu,dimm,pair);
diff --git a/util/subs.c b/util/subs.c
index 2ffcd01..73e5259 100644
--- a/util/subs.c
+++ b/util/subs.c
@@ -403,7 +403,7 @@ int get_errno(void)
/* For a list of all IANA enterprise mfg vendor numbers,
* see http://www.iana.org/assignments/enterprise-numbers
* Product numbers are different for each mfg vendor. */
-#define N_MFG 47
+#define N_MFG 48
static struct { int val; char *pstr; } mfgs[N_MFG] = {
{0, " "},
{0x0000BA, "Toshiba"},
@@ -429,6 +429,7 @@ static struct { int val; char *pstr; } mfgs[N_MFG] = {
{ 20569, "Inventec ESC"},
{ 24673, "ServerEngines"},
{ 27768, "NAT"},
+ {VENDOR_MITAC, "MiTAC"}, /*=6653.*/
{VENDOR_CISCO, "Cisco"}, /*=5771.*/
{VENDOR_IBM, "IBM"}, /*0x000002*/
{VENDOR_NEWISYS, "Newisys"}, /*=9237. */
diff --git a/util/ilan.c b/util/ilan.c
index 4f32674..161e40e 100644
--- a/util/ilan.c
+++ b/util/ilan.c
@@ -3,12 +3,13 @@
*
* Author: arcress at users.sourceforge.net
* Copyright (c) 2009 Kontron America, Inc.
+ * Copyright (c) 2001-2008, Intel Corporation
*
* Abstract:
* This tool sets up the custom Platform Event Filter for the panicSEL
* record (0x20, OS Critical Stop) to send a PEF SNMP alert for Linux
- * panics. It also configures the BMC LAN parameters, which are needed
- * to support PEF alerts.
+ * panics.
*
* ----------- Change History -----------------------------------------------
* 10/16/01 Andy Cress - created
@@ -335,6 +336,8 @@ static int ngood = 0; /* number of good results */
static int lasterr = 0; /* value of the last error */
static char fCustomPEF = 0; /* =1 if -j to input a custom PEF record */
static char fSetPEFOks = 0; /* =1 if -k to set PEF OK rules */
+static char fGranular = 0; /* =1 if want to skip setting SOL & params 10-15 */
+static char fSkipGwyMAC = 0; /* =1 do not try to set gateway MAC */
static char fdisable = 0;
static char fenable = 0; /* =1 to config BMC LAN and PEF */
static char fpefenable = 0; /* =1 enable PEF if Alert Dest is specified */
@@ -1184,6 +1187,12 @@ SetLanEntry (uchar subfunc, LAN_RECORD * pLanRecord, int reqlen)
int status;
uchar completionCode;
+ if (fGranular == 1) { /* if -W skip some lan parameters */
+ if (subfunc >= 10 && subfunc <= 15 ) {
+ if (fdebug) printf ("SetLanEntry(%d) skipped due to -W\n", subfunc);
+ return(0);
+ }
+ }
if (pLanRecord == NULL) {
if (fdebug)
printf ("SetLanEntry(%d): error, input buffer is NULL\n", subfunc);
@@ -2550,7 +2559,8 @@ Get_Mac (uchar * ipadr, uchar * macadr, char *nodname)
printf (" (ERROR_INVALID_USER_BUFFER)\n");
break;
case ERROR_BAD_NET_NAME:
- printf (" (ERROR_GEN_FAILURE)\n");
+ memcpy (macadr, rggwymac, MAC_LEN);
+ printf (" (ERROR_BAD_NET_NAME)\n");
break;
case ERROR_BUFFER_OVERFLOW:
printf (" (ERROR_BUFFER_OVERFLOW)\n");
@@ -3310,7 +3320,7 @@ Get_IPMac_Addr ()
}
else
fgetmac = 1;
- if (fgetmac && IpIsValid (rggwyip) && !MacIsValid (rggwymac))
+ if (fgetmac && IpIsValid(rggwyip) && !MacIsValid(rggwymac))
Get_Mac (rggwyip, rggwymac, NULL); /*gwy mac not specified, so get mac */
/* Get the Alert Destination IP */
@@ -3424,7 +3434,7 @@ Get_IPMac_Addr ()
}
} /*endif local */
}
- if (!MacIsValid (rgdestmac)) { /* if MAC not vaild or user-specified */
+ if (!MacIsValid(rgdestmac)) { /* if MAC not vaild or user-specified */
/* Use arping to get MAC from alertname or IP */
Get_Mac (rgdestip, rgdestmac, alertname);
}
@@ -3697,7 +3707,7 @@ GetSerialOverLan (uchar chan, uchar bset, uchar block)
}
}
if (fIPMI20) {
- if (vend_id != VENDOR_IBM) {
+ if ((vend_id != VENDOR_IBM) && (vend_id != VENDOR_MITAC)) {
/* IBM 0x00DC returns invalid cmd for SOL Payload commands. */
if (!fcanonical) {
requestData[0] = chan;
@@ -3793,6 +3803,10 @@ SetupSerialOverLan (int benable)
ushort getsolcmd;
uchar bchan, b;
+ if (fGranular == 1) {
+ if (fdebug) printf ("SetupSerialOverLan(%d) skipped due to -W\n",benable);
+ return(0);
+ }
if (fIPMI20 && fSOL20) {
setsolcmd = SET_SOL_CONFIG2;
getsolcmd = GET_SOL_CONFIG2;
@@ -4097,7 +4111,7 @@ main(int argc, char **argv)
/* available opt chars: y O Q + = ~ _ */
while ((c =
getopt (argc, argv,
- "a:b:cdef:gh:i:j:klm:n:op:q:rstu:v:w:xy:z#::A:B:C:DEF:G:H:I:J:K:L:M:N:OP:Q:R:S:T:U:V:X:YZ:?"))
+ "a:b:cdef:gh:i:j:klm:n:op:q:rstu:v:w:xy:z#::A:B:C:DEF:G:H:I:J:K:L:M:N:OP:Q:R:S:T:U:V:WX:YZ:?"))
!= EOF)
{
switch (c) {
@@ -4165,6 +4179,12 @@ main(int argc, char **argv)
}
j++;
break;
+ case 'W': /* W = granular, want to skip setting SOL, params 10-15 */
+ fGranular = 1;
+ //++++ if (fdebug)
+ printf ("fGranular = %d\n", fGranular);
+ j++;
+ break;
case 'i': /* eth interface (ifname) */
fsetifn = 1;
i = sizeof (ifname);
@@ -4397,6 +4417,7 @@ main(int argc, char **argv)
printf (" -K (Kontron) IPMI hostname to set\n");
printf (" -Q VLAN Priority (default =0)\n");
printf (" -O Force LAN security: no null user, cipher 0 off\n");
+ printf (" -W Want to set limited LAN parameters, skip 10,11,12,13,SOL\n");
print_lan_opt_usage (0);
ret = ERR_USAGE;
goto do_exit;
@@ -4454,6 +4475,15 @@ main(int argc, char **argv)
pefmax = 16;
fsharedMAC = 0; /* not-shared BMC LAN port */
}
+ else if (vend_id == VENDOR_MITAC) { /* MiTAC = 6653. */
+ fsharedMAC = 0; /* not-shared BMC LAN port */
+ fSkipGwyMAC = 1; /* do not try to set gateway MAC */
+ fGranular = 1; /* skip setting SOL and params 10-15 */
+ pefdesc = NULL; /* unknown, see PefDesc() */
+ pefnum = 16; /* change CritStop pefnum to 16 */
+ pefmax = 20;
+ if (!fUserPefNum) fAdjustPefNum = 1;
+ }
else if (vend_id == VENDOR_INTEL) { /* Intel = 0x000157 */
pefdesc = &pefdesc1[0]; /*default Intel PEF */
pefmax = 20; /*default Intel PEF */
@@ -5310,7 +5340,7 @@ main(int argc, char **argv)
}
// if (fmBMC) lan_access = 0x04; /*Admin*/
// else lan_access = 0x04; /*Admin*/
- if (!fIPMI10) { /* Get SOL params */
+ if ((!fIPMI10) && (!fGranular)) { /* Get SOL params */
ret = GetSerialOverLan (lan_ch, 0, 0);
if (ret != 0) {
printf ("GetSOL error %d, %s\n", ret, decode_rv(ret));
@@ -5418,6 +5448,7 @@ main(int argc, char **argv)
lasterr = ret;
}
else ngood++;
+ if (fGranular == 0) {
/* clear the gateway IP address */
memset (&LanRecord, 0, 4);
ret = SetLanEntry (12, &LanRecord, 4);
@@ -5436,6 +5467,7 @@ main(int argc, char **argv)
lasterr = ret;
}
else ngood++;
+ }
}
else if (fdisableSOL) {
ret = SetupSerialOverLan (0); /*disable */
@@ -5528,7 +5560,7 @@ main(int argc, char **argv)
lasterr = ret;
}
else ngood++;
- if (MacIsValid (rgmymac)) {
+ if (MacIsValid (rgmymac) && fSkipGwyMAC == 0) {
memcpy (&LanRecord, rgmymac, 6);
ret = SetLanEntry (5, &LanRecord, 6);
if (ret == 0x82) { /*BMC may not allow the MAC to be set */
@@ -5577,6 +5609,7 @@ main(int argc, char **argv)
rgmymac[0], rgmymac[1], rgmymac[2], rgmymac[3], rgmymac[4],
rgmymac[5]);
if (IpIsValid (rgmyip)) {
+ if (fGranular == 0) {
if (lan_ch != gcm_ch) { /*skip if gcm */
LanRecord.data[0] = 0x00; /*disable grat arp while setting IP */
ret = SetLanEntry (10, &LanRecord, 1);
@@ -5587,6 +5620,7 @@ main(int argc, char **argv)
lasterr = ret;
}
}
+ }
LanRecord.data[0] = 0x01; /* static IP address source */
ret = SetLanEntry (4, &LanRecord, 1);
printf ("SetLanEntry(4), ret = %d\n", ret);
@@ -5603,7 +5637,7 @@ main(int argc, char **argv)
lasterr = ret;
}
else ngood++;
- if (MacIsValid (rgmymac)) {
+ if (MacIsValid (rgmymac) && fSkipGwyMAC == 0) {
memcpy (&LanRecord, rgmymac, 6);
ret = SetLanEntry (5, &LanRecord, 6);
if (ret == 0x82) {
@@ -5647,6 +5681,7 @@ main(int argc, char **argv)
}
else ngood++;
}
+ if (fGranular == 0) {
/* if lan_ch == 3, gcm gets error setting grat arp (ccode=0xCD) */
if (lan_ch != gcm_ch) { /*skip if gcm */
/* 01=enable grat arp, 02=enable arp resp, 03=both */
@@ -5666,6 +5701,7 @@ main(int argc, char **argv)
nerrs++;
lasterr = ret;
}
+ }
if ((vend_id == VENDOR_INTEL) && !fmBMC && !fiBMC) {
LanRecord.data[0] = 0x00; /*disable DHCP */
ret = SetLanEntry (194, &LanRecord, 1);
@@ -5701,6 +5737,7 @@ main(int argc, char **argv)
}
}
if (IpIsValid (rggwyip)) {
+ if (fGranular == 0) {
if (!MacIsValid (rggwymac)) /* if gwy MAC not set by user */
ret = Get_Mac (rggwyip, rggwymac, NULL);
printf
@@ -5740,6 +5777,7 @@ main(int argc, char **argv)
lasterr = ret;
}
else ngood++;
+ }
}
if (IpIsValid (rggwy2ip)) {
if (!MacIsValid (rggwy2mac)) /* if gwy2 MAC not set by user */
@@ -5789,7 +5827,7 @@ main(int argc, char **argv)
SELprintf ("SetupSerialOverLan: ret = %d\n", ret);
if (ret != 0) {
nerrs++;
- lasterr = ret;
+ lasterr = ret;
}
else ngood++;
if (!IpIsValid (rgdestip) && IpIsValid (bmcdestip)) {
@@ -3,12 +3,13 @@
*
* Abstract:
- * This tool sets up the custom Platform Event Filter for the panicSEL
+ * This module configures the various IPMI LAN parameters.
+ * It also sets up the custom Platform Event Filter for the panicSEL
* record (0x20, OS Critical Stop) to send a PEF SNMP alert for Linux